@@ -4,7 +4,7 @@ import ircstates, irctokens
 class SASLTestAccount(unittest.TestCase):
     def test_loggedin(self):
         server = ircstates.Server("test")
-        server.parse_tokens(irctokens.tokenise("900 * nick!user@host account"))
+        server.parse_tokens(irctokens.tokenise("900 * nick!user@host account *"))
 
         self.assertEqual(server.nickname, "nick")
         self.assertEqual(server.username, "user")
@@ -13,8 +13,8 @@ class SASLTestAccount(unittest.TestCase):
 
     def test_loggedout(self):
         server = ircstates.Server("test")
-        server.parse_tokens(irctokens.tokenise("900 * nick!user@host account"))
-        server.parse_tokens(irctokens.tokenise("901 * nick1!user1@host1"))
+        server.parse_tokens(irctokens.tokenise("900 * nick!user@host account *"))
+        server.parse_tokens(irctokens.tokenise("901 * nick1!user1@host1 *"))
 
         self.assertEqual(server.nickname, "nick1")
         self.assertEqual(server.username, "user1")
